@@ -207,12 +207,23 @@ class CollaborationConfiguration(object):
         Set `default=True` will make this new workflow the default for the
         collaborative entity type.
         """
+        wfname = u'collaboration workflow for ' + self.etype
+        rset = session.execute('Any W WHERE W name "%(wfname)s",'
+                               '            X name "%(etype)s",'
+                               '            W workflow_of X',
+                               {'wfname': wfname, 'etype': self.etype})
+        if rset:
+            wf = rset.get_entity(0, 0)
+            warn('[collaboration] %s already has a collaboration workflow (%s)'
+                 % (self.etype, wf),
+                 Warning, stacklevel=2)
+            return wf
         rset = session.execute('Any X WHERE X is CWEType, X name %(et)s',
                                {'et': self.etype})
         assert rset, 'cannot find an entity type named %s' % self.etype
         eid = rset[0][0]
         wf = session.create_entity(
-            'Workflow', name=u'collaboration workflow for ' + self.etype,
+            'Workflow', name=wfname,
             workflow_of=eid, reverse_default_workflow=eid if default else None)
         wfs_mutable = wf.add_state(_('wfs_mutable'), initial=True)
         wfs_immutable = wf.add_state(_('wfs_immutable'))
