@@ -24,8 +24,7 @@ from cubicweb.predicates import adaptable, relation_possible
 
 from cubes.container.entities import Container, ContainerClone
 
-COLLABORATIVE_SELECTOR = (relation_possible('frozen') &
-                          relation_possible('collaborates_on', role='object'))
+COLLABORATIVE_SELECTOR = relation_possible('collaborates_on', role='object')
 
 
 class ClonableAdapter(ContainerClone):
@@ -63,13 +62,6 @@ class CollaborativeAdapter(EntityAdapter):
     __regid__ = 'ICollaborative'
     __select__ = COLLABORATIVE_SELECTOR
 
-    @property
-    def frozen(self):
-        return self.entity.frozen
-
-    def set_frozen(self, value):
-        self.entity.cw_set(frozen=value)
-
     @property
     def clones(self):
         rtype, role = self.entity.cw_adapt_to('Container.clone').clone_rtype_role
