@@ -27,7 +27,8 @@ from cubicweb.web.views.actions import CopyAction
 
 
 from cubicweb.predicates import (adaptable, one_line_rset, has_permission,
-                                 score_entity, rql_condition, match_user_groups)
+                                 score_entity, rql_condition,
+                                 match_user_groups, is_in_state)
 from cubicweb.web import action, Redirect, component
 from cubicweb.view import EntityView
 from cubicweb.web.views import primary, uicfg, editcontroller
@@ -37,20 +38,6 @@ _pvs = uicfg.primaryview_section
 _pvs.tag_object_of(('CWUser', 'collaborates_on', '*'), 'attributes')
 
 
-def is_frozen(entity):
-    adapted = entity.cw_adapt_to('ICollaborative')
-    if adapted is not None:
-        return int(adapted.frozen)
-    return 0
-
-
-def is_unfrozen(entity):
-    adapted = entity.cw_adapt_to('ICollaborative')
-    if adapted is not None:
-        return int(not adapted.frozen)
-    return 0
-
-
 def cloned(entity):
     adapted = entity.cw_adapt_to('ICollaborative')
     if adapted is not None:
@@ -65,55 +52,18 @@ def not_cloned(entity):
     return 0
 
 
-class FreezeAction(action.Action):
-    __regid__ = 'collaboration.freeze'
-    __select__ = (action.Action.__select__ & score_entity(is_unfrozen)
-                  & has_permission('update'))
-    title = _('freeze')
-    category = 'moreactions'
-    order = 28
-
-    def url(self):
-        entity = self.cw_rset.get_entity(self.cw_row or 0, self.cw_col or 0)
-        return entity.absolute_url(vid='collaboration.freeze-unfreeze')
-
-
-class UnfreezeAction(action.Action):
-    __regid__ = 'collaboration.unfreeze'
-    # match_user_groups('owners') in the selector because the CanEditContainerHook
-    # revokes the write permission once the entity is frozen, and it suffices
-    # to be an owner of a not cloned frozen entity, to be able to unfreeze it
-    __select__ = (action.Action.__select__ & score_entity(is_frozen) &
-                  score_entity(not_cloned) & match_user_groups('owners'))
-    title = _('unfreeze')
-    category = 'moreactions'
-    order = 29
-
-    def url(self):
-        entity = self.cw_rset.get_entity(self.cw_row or 0, self.cw_col or 0)
-        return entity.absolute_url(vid='collaboration.freeze-unfreeze', value='false')
-
-
-class FreezeUnfreezeView(EntityView):
-    __regid__ = 'collaboration.freeze-unfreeze'
-    __select__ = (EntityView.__select__ &
-                  adaptable('ICollaborative'))
-
-    def entity_call(self, entity, **kwargs):
-        frozen = json.loads(self._cw.form.get('value', 'true'))
-        entity.cw_adapt_to('ICollaborative').set_frozen(frozen)
-        if frozen:
-            msg = self._cw._('%s is now frozen') % entity.dc_title()
-        else:
-            msg = self._cw._('%s is now unfrozen') % entity.dc_title()
-        raise Redirect(entity.absolute_url(__message=msg))
+def clonable(entity):
+    """Return 1 if the entity is clonable according to its workflow state"""
+    collabcfg = entity.container_config.collaboration_config
+    clone_state = collabcfg.clone_state
+    return is_in_state(clone_state).score_entity(entity)
 
 
 class CloneAction(CopyAction):
     """Just a copy action (copy is handled by edit controller below) named 'clone'."""
     __select__ = (CopyAction.__select__ & one_line_rset() &
-                  adaptable('ICollaborative') &
-                  score_entity(is_frozen) & has_permission('add'))
+                  adaptable('ICollaborative') & score_entity(clonable) &
+                  has_permission('add'))
     title = _('clone')
 
     def url(self):
